=======================
rinoh-typeface-webdings
=======================

This package provides the `Webdings`_ 1.03 typeface from Microsoft's `Core
fonts for the Web`_ for use with rinohtype_.

In order to comply with the EULA for these fonts, the font archive is
downloaded during installation of this package.


.. _Webdings: https://en.wikipedia.org/wiki/Webdings
.. _Core fonts for the Web: https://en.wikipedia.org/wiki/Core_fonts_for_the_Web
.. _rinohtype: https://github.com/brechtm/rinohtype#readme
